@@ -13,7 +13,7 @@ class Distro(Module):
     def deploy(self, target, **kw):
 
         target.deploy('infos')
-        target.pip.install('setux_desktop')
+        target.pip.install('setux_plus')
         target.remote('infos')
         target.pip.install('setux_repl')
         target('setux infos')
