@@ -7,8 +7,8 @@ from setux.logger import debug
 class Distro(Module):
     '''Update Config File (sed)
     '''
-    def deploy(self, target, *, cfg, src=None, dst):
-        cont = target.read(cfg, report='quiet')
+    def deploy(self, target, *, cfg, src=None, dst, sudo=None):
+        cont = target.read(cfg, sudo=sudo, report='quiet')
         if dst in cont: return True
         msg = [f'{cfg} <>']
         if src:
@@ -24,10 +24,10 @@ class Distro(Module):
                     updated.append(line)
             if not found:
                 updated.append(dst)
-            target.write(cfg, '\n'.join(updated)+'\n', report='quiet')
+            target.write(cfg, '\n'.join(updated)+'\n', sudo=sudo, report='quiet')
         else:
             msg.append(f'  > {dst}')
-            target.write(cfg, f'{cont}{dst}\n', report='quiet')
+            target.write(cfg, f'{cont}{dst}\n', sudo=sudo, report='quiet')
 
         debug('\n'.join(msg))
         return True
